@@ -12,7 +12,8 @@
 
 import copy
 
-import mock
+from unittest import mock
+
 import six
 
 from gbpautomation.heat.engine.resources import grouppolicy
@@ -164,7 +165,8 @@ l2_policy_template = '''
         "description": "test L2 policy resource",
         "l3_policy_id": "l3-policy-id",
         "shared": True,
-        "reuse_bd": "other-l2p"
+        "reuse_bd": "other-l2p",
+        "network_id": "network-id"
       }
     }
   }
@@ -993,6 +995,7 @@ class L2PolicyTest(HeatTestCase):
                 "l3_policy_id": "l3-policy-id",
                 "shared": True,
                 "reuse_bd": "other-l2p",
+                "network_id": "network-id",
             }
         }
         tdict = {'l2_policy': {'id': '5678'}}
@@ -1023,6 +1026,7 @@ class L2PolicyTest(HeatTestCase):
                 "l3_policy_id": "l3-policy-id",
                 "shared": True,
                 "reuse_bd": "other-l2p",
+                "network_id": "network-id",
             }
         }
         exc = grouppolicy.NeutronClientException()
